@@ -1,6 +1,14 @@
 # Copyright 2015 by Roger S. Bivand, Yongwan Chun and Daniel A. Griffith
 
 l_max <- function(lw, zero.policy=TRUE, control=list()) {
+    .Deprecated("spatialreg::l_max", msg="Function l_max moved to the spatialreg package")
+#    if (!requireNamespace("spatialreg", quietly=TRUE))
+#      stop("install the spatialreg package")
+    if (requireNamespace("spatialreg", quietly=TRUE)) {
+        return(spatialreg::l_max(lw=lw, zero.policy=zero.policy, control=control))
+    }
+    warning("install the spatialreg package")
+#  if (FALSE) {
     tol <- control$tol
     if (is.null(tol)) tol <- .Machine$double.eps^(1/2)
     stopifnot(is.numeric(tol))
@@ -44,7 +52,7 @@ l_max <- function(lw, zero.policy=TRUE, control=list()) {
         }
         lambda1 <- numer/denom
         if (trace) cat(k, lambda1, numer, denom, constant, "\n")
-#        if (abs(lamlag - lambda1) < tol) {
+#        if (abs(lamlag - lambda1) < tol) 
         if (abs(constant0 - constant) < tol) {
             lambda1 <- constant
             msg <- "converged"
@@ -59,7 +67,7 @@ l_max <- function(lw, zero.policy=TRUE, control=list()) {
             msg <- "iteration limit exceeded"
             keepgoing <- FALSE
             break
-      }
+        }
     }
     attr(lambda1, "k") <- k
     attr(lambda1, "msg") <- msg
@@ -67,9 +75,18 @@ l_max <- function(lw, zero.policy=TRUE, control=list()) {
     attr(lambda1, "e1") <- nik
     lambda1
 }
+#}
 
 
 lextrB <- function(lw, zero.policy=TRUE, control=list()) {
+    .Deprecated("spatialreg::lextrB", msg="Function lextrB moved to the spatialreg package")
+#    if (!requireNamespace("spatialreg", quietly=TRUE))
+#      stop("install the spatialreg package")
+    if (requireNamespace("spatialreg", quietly=TRUE)) {
+      return(spatialreg::lextrB(lw=lw, zero.policy=zero.policy, control=control))
+    }
+    warning("install the spatialreg package")
+#  if (FALSE) {
 # must be binary listw object
   stopifnot(lw$style == "B")
   if (!is.symmetric.glist(lw$neighbours, lw$weights))
@@ -113,7 +130,9 @@ lextrB <- function(lw, zero.policy=TRUE, control=list()) {
     e1=attr(resl1, "e1")/c(resl1))
   res
 }
+#}
 
+#if (FALSE) {
 lminC_2.3 <- function(lw, y, sse.new, crd, zero.policy=TRUE,
   control=list(
   trace=TRUE,
@@ -192,8 +211,9 @@ lminC_2.3 <- function(lw, y, sse.new, crd, zero.policy=TRUE,
   attr(lambda.n, "en") <- y
   lambda.n
 }
+#}
 
-
+#if (FALSE) {
 lminC_2.2 <- function(lw, res_2.1, crd, zero.policy=TRUE,
   control=list(
   trace=TRUE,
@@ -248,12 +268,15 @@ lminC_2.2 <- function(lw, res_2.1, crd, zero.policy=TRUE,
   if (trace) cat("Phase 2.2:", n.switch3, "\n")
   y
 }
+#}
 
+#if (FALSE) {
 lminC_2.1 <- function(lw, y, crd, zero.policy=TRUE,
   control=list(
   trace=TRUE,
   tol=.Machine$double.eps^(1/2),
   maxiter=6*(length(lw$neighbours)-2), useC=FALSE)) {
+
 ## 2-1. updaing Ei with lag.Ei based on comparison of test1 (t1)
 # and test2 (t2)
 #
@@ -337,4 +360,5 @@ lminC_2.1 <- function(lw, y, crd, zero.policy=TRUE,
   attr(y, "lm.y") <- lm.y
   y
 }
+#}
 
